#
# spec file for package scantailor
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           scantailor
Version:        0.9.11.1
Release:        6.4
Summary:        Interactive post-processing tool for scanned pages
License:        GPL-3.0+
Group:          Productivity/Graphics/Other
Url:            http://scantailor.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Source1:        %{name}-icons.tar.bz2
BuildRequires:  boost-devel >= 1.42
BuildRequires:  cmake
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt4-devel >= 4.5
BuildRequires:  update-desktop-files
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Scan Tailor is an interactive post-processing tool for scanned pages.
It performs operations such as page splitting, deskewing,
adding/removing borders and others. You give it raw scans, and you get
pages ready to be printed or assembled into a PDF or DJVU file.

%package        cli
Summary:        Command line post-processing tool for scanned pages
Group:          Productivity/Graphics/Other

%description    cli
Scan Tailor is an interactive post-processing tool for scanned pages.
It performs operations such as page splitting, deskewing,
adding/removing borders and others. You give it raw scans, and you get
pages ready to be printed or assembled into a PDF or DJVU file.

This package provides command line version of scantailor.

%prep
%setup -q -a 1
cp -p resources/icons/{COPYING,COPYING.icons}

%build
%cmake ..
make %{?_smp_mflags} VERBOSE=1

%install
%cmake_install

for s in 256 128 96 72 64 48 32 16 ; do
install -Dm 0644 scantailor-icons/scantailor-${s}.png \
    %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/scantailor.png
done
install -Dm 0644 resources/appicon.svg \
    %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/scantailor.svg
# Create desktop-file
cat > %{name}.desktop << EOF
[Desktop Entry]
Name=Scan Tailor
GenericName=Post-Processing Tool for Scanned Pages
GenericName[ru]=Обработка отсканированных страниц
Type=Application
Exec=scantailor
Icon=scantailor
Categories=Graphics;Scanning;Qt;
Comment=Interactive Post-Processing Tool for Scanned Pages
Comment[ru]=Интерактивная обработка отсканированных страниц
StartupNotify=true
Terminal=false
EOF
%suse_update_desktop_file -i %{name}

%post
%icon_theme_cache_post

%postun
%icon_theme_cache_postun

%files
%defattr(-,root,root,-)
%doc COPYING GPL3.txt resources/icons/COPYING.icons
%{_datadir}/%{name}
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/%{name}.*

%files cli
%defattr(-,root,root,-)
%{_bindir}/%{name}-cli

%changelog
* Sat Jan 24 2015 dmitry_r@opensuse.org
- Move command line interface to separate package
* Mon Dec 29 2014 dmitry_r@opensuse.org
- Use %%cmake macros
* Sun Mar  3 2013 asterios.dramis@gmail.com
- Update to 0.9.11.1:
  * Fixed a bug affecting binarization quality in Mixed output mode.
  * Fixed borders being filled with cyan instead of white.
  * Avoid creating unwanted directories for projects requiring relinking.
  * Cosmetic improvements in Relinking dialog.
  * New translation: Brazilian Portuguese.
* Wed Jan 18 2012 lazy.kent@opensuse.org
- Update to 0.9.11.
  * Ability to fix DPI of source images in an existing project.
  * Project portability through resource relinking.
  * It's now possible to save your project in an out-of-memory
    situation.
  * New translations: Spanish, Ukrainean.
- Corrected icons size.
* Mon Aug  1 2011 lazy.kent@opensuse.org
- Update to 0.9.10.
  + Page dewarping functionality.
  + Command-line version.
  + Ability to apply content box to to multiple pages.
  + Ability to apply margins to odd and even pages separately.
  + New translations: Italian, Czech, Polish, Slovak, Traditional
    Chinese
  + Bug fixes, including a couple of crashes.
- Dropped tabbed_widget patch (don't build against Qt 4.4 anymore).
- Build requires boost-devel >= 1.42 and libqt4-devel >= 4.5.
- Install icons of different sizes.
- Added icon_theme_cache_post/un macro.
- Corrected License tag.
- Use full URL for source.
* Sun Oct 24 2010 lazy.kent.suse@gmail.com
- Update to 0.9.9.2.
  + Fixed page sorting issues on Linux.
  + Fixed improper calculation of cut-off page outline.
  + Fixed pages re-appearing in a project after being removed
    half-by-half.
  + German and French translations were added.
  + Compatibility with the latest version of boost.
- Dropped boost compatibility patch.
* Sat Sep  4 2010 lazy.kent.suse@gmail.com
- Fixed build against boost-1.44.
* Sun Jun 27 2010 lazy.kent.suse@gmail.com
- Update to 0.9.9.1
  + A few user interaction bugs were fixed.
* Mon Jun 14 2010 lazy.kent.suse@gmail.com
- Update to 0.9.9.
  + New feature: Fill Zones.
  + New feature: ordering pages by content box dimensions.
  + New naming scheme for output files.
  + Bugfixes, including two possible crashes.
- Renamed COPYING to COPYING.icons.
* Fri Apr 30 2010 lazy.kent.suse@gmail.com
- Update to 0.9.8.1.
  + Fixed despeckling aggressiveness depending on semi-random factors.
  + Fixed cancelling of new page insertion not always working.
  + For consistency, pure black and white colors are reserved in
    Color / Grayscale mode as well.
  + Minor fixes and improvements at Deskew and Page Layout stages.
- Dropped obsolete despeckling patch.
* Sun Apr 11 2010 lazy.kent.suse@gmail.com
- Fix a problem with despeckling.
* Sat Apr  3 2010 lazy.kent.suse@gmail.com
- Update to 0.9.8.
  + Despeckling: improved algorithm, adjustable, with visualization.
  + Increased binarization adjustment range.
  + Fixed a few crashes.
  + Japanese translation.
  + Disabled OpenGL based UI acceleration due to its instability.
- Dropped obsolete gcc45 patch.
- URL changed to English.
* Sun Feb 21 2010 lazy.kent.suse@gmail.com
- Fixed build with GCC 4.5.
* Tue Jan  5 2010 lazy.kent.suse@gmail.com
- Apply widget patch for openSUSE < 11.2 only.
* Sun Jan  3 2010 lazy.kent.suse@gmail.com
- Initial package created.
- Fixed build with Qt 4.4.x.
